@@ -87,6 +87,7 @@ wb_save <- function(wb, path = NULL, overwrite = TRUE) {
 #' @param withFilter If `TRUE`, add filters to the column name row. NOTE can only have one filter per worksheet.
 #' @param name If not NULL, a named region is defined.
 #' @param sep Only applies to list columns. The separator used to collapse list columns to a character vector e.g. sapply(x$list_column, paste, collapse = sep).
+#' @param applyCellStyle Should we write cell styles to the workbook
 #' @param removeCellStyle keep the cell style?
 #' @param na.strings na.strings
 #' @export
@@ -110,6 +111,7 @@ wb_add_data <- function(
     withFilter      = FALSE,
     name            = NULL,
     sep             = ", ",
+    applyCellStyle  = TRUE,
     removeCellStyle = FALSE,
     na.strings
 ) {
@@ -117,7 +119,7 @@ wb_add_data <- function(
 
   if (missing(na.strings)) na.strings <- substitute()
 
-  wb$clone()$add_data(
+  wb$clone(deep = TRUE)$add_data(
     sheet           = sheet,
     x               = x,
     startCol        = startCol,
@@ -130,6 +132,7 @@ wb_add_data <- function(
     withFilter      = withFilter,
     name            = name,
     sep             = sep,
+    applyCellStyle  = applyCellStyle,
     removeCellStyle = removeCellStyle,
     na.strings      = na.strings
   )
@@ -166,6 +169,8 @@ wb_add_data <- function(
 #' @param lastColumn logical. If TRUE, the last column is bold
 #' @param bandedRows logical. If TRUE, rows are colour banded
 #' @param bandedCols logical. If TRUE, the columns are colour banded
+#' @param applyCellStyle Should we write cell styles to the workbook
+#' @param removeCellStyle keep the cell style?
 #' @param na.strings optional
 #'
 #' @details columns of x with class Date/POSIXt, currency, accounting,
@@ -193,6 +198,8 @@ wb_add_data_table <- function(
     lastColumn  = FALSE,
     bandedRows  = TRUE,
     bandedCols  = FALSE,
+    applyCellStyle  = TRUE,
+    removeCellStyle = FALSE,
     na.strings
 ) {
   assert_workbook(wb)
@@ -215,6 +222,8 @@ wb_add_data_table <- function(
     lastColumn  = lastColumn,
     bandedRows  = bandedRows,
     bandedCols  = bandedCols,
+    applyCellStyle  = applyCellStyle,
+    removeCellStyle = removeCellStyle,
     na.strings  = na.strings
   )
 }
@@ -243,6 +252,8 @@ wb_add_data_table <- function(
 #' @param xy An alternative to specifying `startCol` and
 #' `startRow` individually.  A vector of the form
 #' `c(startCol, startRow)`.
+#' @param applyCellStyle Should we write cell styles to the workbook
+#' @param removeCellStyle keep the cell style?
 #' @family workbook wrappers
 #' @export
 wb_add_formula <- function(
@@ -253,7 +264,9 @@ wb_add_formula <- function(
     startRow = 1,
     dims     = rowcol_to_dims(startRow, startCol),
     array    = FALSE,
-    xy       = NULL
+    xy       = NULL,
+    applyCellStyle  = TRUE,
+    removeCellStyle = FALSE
 ) {
   assert_workbook(wb)
   wb$clone()$add_formula(
@@ -263,7 +276,9 @@ wb_add_formula <- function(
     startRow = startRow,
     dims     = dims,
     array    = array,
-    xy       = xy
+    xy       = xy,
+    applyCellStyle  = applyCellStyle,
+    removeCellStyle = removeCellStyle
   )
 }
 
@@ -773,7 +788,7 @@ wb_remove_worksheet <- function(wb, sheet = current_sheet()) {
 #'
 #' wb$add_data("S1", iris)
 #' wb$add_data_table("S1", x = iris, startCol = 10) ## font colour does not affect tables
-wb_set_base_font <- function(wb, fontSize = 11, fontColour = "black", fontName = "Calibri") {
+wb_set_base_font <- function(wb, fontSize = 11, fontColour = wb_colour(theme = "1"), fontName = "Calibri") {
   assert_workbook(wb)
   wb$clone()$set_base_font(
     fontSize   = fontSize,
@@ -1131,7 +1146,7 @@ wb_protect_worksheet <- function(
 #' wb <- wb_workbook()
 #' wb$add_worksheet("S1")
 #' wb_protect(wb, protect = TRUE, password = "Password", lockStructure = TRUE)
-#' 
+#'
 #' # Remove the protection
 #' wb_protect(wb, protect = FALSE)
 #'
@@ -1538,7 +1553,7 @@ wb_set_sheet_visibility <- function(wb, sheet = current_sheet(), value) {
 #' wb$add_page_break(sheet = 1, row = 10)
 #' wb$add_page_break(sheet = 1, row = 20)
 #' wb$add_page_break(sheet = 1, col = 2)
-#' 
+#'
 #' ## In Excel: View tab -> Page Break Preview
 wb_add_page_break <- function(wb, sheet = current_sheet(), row = NULL, col = NULL) {
   assert_workbook(wb)
@@ -1931,7 +1946,7 @@ wb_add_style <- function(wb, style = NULL, style_name = NULL) {
 #' @export
 wb_get_cell_style <- function(wb, sheet = current_sheet(), dims) {
   assert_workbook(wb)
-  wb$get_cell_style(sheet, dims)
+  wb$clone()$get_cell_style(sheet, dims)
 }
 
 #' @rdname cell_style
@@ -1940,7 +1955,8 @@ wb_get_cell_style <- function(wb, sheet = current_sheet(), dims) {
 #' @export
 wb_set_cell_style <- function(wb, sheet = current_sheet(), dims, style) {
   assert_workbook(wb)
-  wb$clone()$set_cell_style(sheet, dims, style)
+  # needs deep clone for nested calls as in styles vignette copy cell styles
+  wb$clone(deep = TRUE)$set_cell_style(sheet, dims, style)
 }
 
 #' add border for cell region
