@@ -5,12 +5,12 @@ test_that("get_base_font works", {
     list(
       size = list(val = "11"),
       # should this be "#000000"?
-      colour = list(rgb = "FF000000"),
+      colour = list(theme = "1"),
       name = list(val = "Calibri")
     )
   )
 
-  wb$set_base_font( fontSize = 9, fontName = "Arial", fontColour = "red")
+  wb$set_base_font(fontSize = 9, fontName = "Arial", fontColour = wb_colour("red"))
   expect_equal(
     wb$get_base_font(),
     list(
